all.Indss<-function(){
     cat("\n")
     note_for_Indss_input()
     cat("\n")
     note_for_close_window()
     IndSSpar<-data.frame(parameter=c("Gender","bw (kg)","Rit","D (mg)","tau (hr)","ts (hr)","c (mg/L)"),value=c(0))
     IndSSpar<-edit(IndSSpar)
##     IndSSpar<-ycheck(IndSSpar)
     Ind.ss(IndSSpar[7,2],IndSSpar[5,2],IndSSpar[6,2],IndSSpar[4,2],IndSSpar[2,2],IndSSpar[3,2],IndSSpar[1,2])
     note_for_convergence_plots()
     convergence_plots_sep()
     note_for_Indss_output()
     show(samplesStats("*"))
     cat("\n") 
     C<-Indcpr(samplesStats("ka"),IndSSpar[4,2],IndSSpar[5,2],IndSSpar[6,2])
     sim<-matrix(C[1 ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Cmss_pr (mg/L)")
     output1<-coutput
     show(coutput)
     C<-Indcpr(samplesStats("ka"),IndSSpar[4,2],IndSSpar[5,2],IndSSpar[6,2])
     sim<-matrix(C[1 ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Ctss_pr (mg/L)")
     output2<-coutput
     show(coutput)    
     cat("\n")  
     Ind.more()
}